"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

require("core-js/modules/es.array.concat");

require("core-js/modules/es.array.filter");

require("core-js/modules/es.array.find");

require("core-js/modules/es.array.flat-map");

require("core-js/modules/es.array.for-each");

require("core-js/modules/es.array.join");

require("core-js/modules/es.array.map");

require("core-js/modules/es.array.slice");

require("core-js/modules/es.array.unscopables.flat-map");

require("core-js/modules/es.function.name");

require("core-js/modules/es.regexp.constructor");

require("core-js/modules/es.regexp.exec");

require("core-js/modules/es.regexp.to-string");

require("core-js/modules/es.string.match");

require("core-js/modules/web.dom-collections.for-each");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _global = _interopRequireDefault(require("global"));

var _ansiColors = require("ansi-colors");

var _register = _interopRequireDefault(require("babel-plugin-require-context-hook/register"));

var _plur = _interopRequireDefault(require("plur"));

var _reactElementToJsxString = _interopRequireDefault(require("react-element-to-jsx-string"));

var _server = require("@storybook/core/server");

var storybook = _interopRequireWildcard(require("@storybook/react"));

var _utils = require("./utils");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/* eslint-disable global-require, no-console, no-underscore-dangle */

/* eslint-disable import/no-dynamic-require, @typescript-eslint/no-var-requires */
(0, _register["default"])();

var isFile = function isFile(file) {
  try {
    return _fs["default"].lstatSync(file).isFile();
  } catch (err) {
    return false;
  }
};

var extensions = ['ts', 'tsx', 'js', 'jsx'];

var resolveFile = function resolveFile(configDir, filenames) {
  return filenames.flatMap(function (filename) {
    return extensions.map(function (ext) {
      return _path["default"].join(configDir, "".concat(filename, ".").concat(ext));
    });
  }).find(isFile) || false;
};

var getPreviewFile = function getPreviewFile(configDir) {
  return resolveFile(configDir, ['preview', 'config']);
};

var getMainFile = function getMainFile(configDir) {
  return resolveFile(configDir, ['main']);
};

var getConfigPathParts = function getConfigPathParts(input) {
  var configDir = _path["default"].resolve(input);

  if (_fs["default"].lstatSync(configDir).isDirectory()) {
    var output = {
      files: [],
      stories: []
    };
    var preview = getPreviewFile(configDir);
    var main = getMainFile(configDir);

    if (preview) {
      output.files.push(preview);
    }

    if (main) {
      var _require = require(main),
          _require$stories = _require.stories,
          stories = _require$stories === void 0 ? [] : _require$stories;

      output.stories = stories.map(function (pattern) {
        var _toRequireContext = (0, _server.toRequireContext)(pattern),
            basePath = _toRequireContext.path,
            recursive = _toRequireContext.recursive,
            match = _toRequireContext.match;

        return _global["default"].__requireContext(configDir, basePath, recursive, new RegExp(match.slice(1, -1)));
      });
    }

    return output;
  }

  return {
    files: [configDir],
    stories: []
  };
};

var configure = function configure(options) {
  var configDir = options.configDir;

  var _getConfigPathParts = getConfigPathParts(configDir),
      files = _getConfigPathParts.files,
      stories = _getConfigPathParts.stories;

  files.forEach(function (file) {
    return require(file);
  });

  if (stories.length > 0) {
    storybook.configure(stories, false);
  }
};

var _default = function _default(configDir, _ref) {
  var outFile = _ref.outFile;
  configure({
    configDir: configDir
  });
  var snippets = storybook.raw().map(function (_ref2) {
    var group = _ref2.kind,
        name = _ref2.name,
        getOriginal = _ref2.getOriginal,
        _ref2$parameters = _ref2.parameters;
    _ref2$parameters = _ref2$parameters === void 0 ? {} : _ref2$parameters;
    var playroom = _ref2$parameters.playroom;

    var _getOptions = (0, _utils.getOptions)(playroom),
        disabled = _getOptions.disabled,
        reactElementToJSXStringOptions = _getOptions.reactElementToJSXStringOptions;

    if (disabled) {
      return undefined;
    }

    console.log("Generating ".concat((0, _ansiColors.yellow)([group, name].join('/')), " snippet..."));
    var element = getOriginal()();
    var code = (0, _reactElementToJsxString["default"])(element, reactElementToJSXStringOptions);
    return {
      group: group,
      name: name,
      code: code
    };
  }).filter(Boolean);

  _fs["default"].writeFileSync(_path["default"].resolve(process.cwd(), outFile), JSON.stringify(snippets, null, 2));

  console.log("\n".concat(snippets.length, " ").concat((0, _plur["default"])('snippet', snippets.length), " generated."));
};

exports["default"] = _default;